# PersonalDetailsV30Rc1

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**last_modified_date** | [**LastModifiedDateV30Rc1**](LastModifiedDateV30Rc1.md) |  | [optional] 
**name** | [**NameV30Rc1**](NameV30Rc1.md) |  | [optional] 
**other_names** | [**OtherNamesV30Rc1**](OtherNamesV30Rc1.md) |  | [optional] 
**biography** | [**BiographyV30Rc1**](BiographyV30Rc1.md) |  | [optional] 
**path** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

